import { Client } from '../client';
import type { Models } from '../models';
export declare class Backups {
    client: Client;
    constructor(client: Client);
    /**
     * List all archives for a project.
     *
     * @param {string[]} queries
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupArchiveList>}
     */
    listArchives(queries?: string[]): Promise<Models.BackupArchiveList>;
    /**
     * Create a new archive asynchronously for a project.
     *
     * @param {string[]} services
     * @param {string} resourceId
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupArchive>}
     */
    createArchive(services: string[], resourceId?: string): Promise<Models.BackupArchive>;
    /**
     * Get a backup archive using it&#039;s ID.
     *
     * @param {string} archiveId
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupArchive>}
     */
    getArchive(archiveId: string): Promise<Models.BackupArchive>;
    /**
     * Delete an existing archive for a project.
     *
     * @param {string} archiveId
     * @throws {AppwriteException}
     * @returns {Promise<{}>}
     */
    deleteArchive(archiveId: string): Promise<{}>;
    /**
     * List all policies for a project.
     *
     * @param {string[]} queries
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupPolicyList>}
     */
    listPolicies(queries?: string[]): Promise<Models.BackupPolicyList>;
    /**
     * Create a new backup policy.
     *
     * @param {string} policyId
     * @param {string[]} services
     * @param {number} retention
     * @param {string} schedule
     * @param {string} name
     * @param {string} resourceId
     * @param {boolean} enabled
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupPolicy>}
     */
    createPolicy(policyId: string, services: string[], retention: number, schedule: string, name?: string, resourceId?: string, enabled?: boolean): Promise<Models.BackupPolicy>;
    /**
     * Get a backup policy using it&#039;s ID.
     *
     * @param {string} policyId
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupPolicy>}
     */
    getPolicy(policyId: string): Promise<Models.BackupPolicy>;
    /**
     * Update an existing policy using it&#039;s ID.
     *
     * @param {string} policyId
     * @param {string} name
     * @param {number} retention
     * @param {string} schedule
     * @param {boolean} enabled
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupPolicy>}
     */
    updatePolicy(policyId: string, name?: string, retention?: number, schedule?: string, enabled?: boolean): Promise<Models.BackupPolicy>;
    /**
     * Delete a policy using it&#039;s ID.
     *
     * @param {string} policyId
     * @throws {AppwriteException}
     * @returns {Promise<{}>}
     */
    deletePolicy(policyId: string): Promise<{}>;
    /**
     * Create and trigger a new restoration for a backup on a project.
     *
     * @param {string} archiveId
     * @param {string[]} services
     * @param {string} newResourceId
     * @param {string} newResourceName
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupRestoration>}
     */
    createRestoration(archiveId: string, services: string[], newResourceId?: string, newResourceName?: string): Promise<Models.BackupRestoration>;
    /**
     * List all backup restorations for a project.
     *
     * @param {string[]} queries
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupRestorationList>}
     */
    listRestorations(queries?: string[]): Promise<Models.BackupRestorationList>;
    /**
     * Get the current status of a backup restoration.
     *
     * @param {string} restorationId
     * @throws {AppwriteException}
     * @returns {Promise<Models.BackupRestoration>}
     */
    getRestoration(restorationId: string): Promise<Models.BackupRestoration>;
}
