import { Client } from '../client';
import type { Models } from '../models';
import { ConsoleResourceType } from '../enums/console-resource-type';
export declare class Console {
    client: Client;
    constructor(client: Client);
    /**
     * Recieve the details of a compaign using it&#039;s ID.
     *
     * @param {string} campaignId
     * @throws {AppwriteException}
     * @returns {Promise<Models.Campaign>}
     */
    getCampaign(campaignId: string): Promise<Models.Campaign>;
    /**
     * Get the details of a coupon using it&#039;s coupon ID.
     *
     * @param {string} couponId
     * @throws {AppwriteException}
     * @returns {Promise<Models.Coupon>}
     */
    getCoupon(couponId: string): Promise<Models.Coupon>;
    /**
     * Return a list of all available plans.
     *
     * @throws {AppwriteException}
     * @returns {Promise<Models.BillingPlanList>}
     */
    plans(): Promise<Models.BillingPlanList>;
    /**
     * Create a new membership for an account to a program.
     *
     * @param {string} programId
     * @throws {AppwriteException}
     * @returns {Promise<Models.Organization<Preferences>>}
     */
    createProgramMembership<Preferences extends Models.Preferences>(programId: string): Promise<Models.Organization<Preferences>>;
    /**
     * Get all available regions for the console.
     *
     * @throws {AppwriteException}
     * @returns {Promise<Models.ConsoleRegionList>}
     */
    regions(): Promise<Models.ConsoleRegionList>;
    /**
     * Check if a resource ID is available.
     *
     * @param {string} value
     * @param {ConsoleResourceType} type
     * @throws {AppwriteException}
     * @returns {Promise<{}>}
     */
    getResource(value: string, type: ConsoleResourceType): Promise<{}>;
    /**
     * Create a new source.
     *
     * @param {string} ref
     * @param {string} referrer
     * @param {string} utmSource
     * @param {string} utmCampaign
     * @param {string} utmMedium
     * @throws {AppwriteException}
     * @returns {Promise<{}>}
     */
    createSource(ref?: string, referrer?: string, utmSource?: string, utmCampaign?: string, utmMedium?: string): Promise<{}>;
    /**
     * Get all Environment Variables that are relevant for the console.
     *
     * @throws {AppwriteException}
     * @returns {Promise<Models.ConsoleVariables>}
     */
    variables(): Promise<Models.ConsoleVariables>;
}
