import { Client } from '../client';
import type { Models } from '../models';
import { StatusCode } from '../enums/status-code';
export declare class Proxy {
    client: Client;
    constructor(client: Client);
    /**
     * Get a list of all the proxy rules. You can use the query params to filter your results.
     *
     * @param {string[]} queries
     * @param {string} search
     * @throws {AppwriteException}
     * @returns {Promise<Models.ProxyRuleList>}
     */
    listRules(queries?: string[], search?: string): Promise<Models.ProxyRuleList>;
    /**
     * Create a new proxy rule for serving Appwrite&#039;s API on custom domain.
     *
     * @param {string} domain
     * @throws {AppwriteException}
     * @returns {Promise<Models.ProxyRule>}
     */
    createAPIRule(domain: string): Promise<Models.ProxyRule>;
    /**
     * Create a new proxy rule for executing Appwrite Function on custom domain.
     *
     * @param {string} domain
     * @param {string} functionId
     * @param {string} branch
     * @throws {AppwriteException}
     * @returns {Promise<Models.ProxyRule>}
     */
    createFunctionRule(domain: string, functionId: string, branch?: string): Promise<Models.ProxyRule>;
    /**
     * Create a new proxy rule for to redirect from custom domain to another domain.
     *
     * @param {string} domain
     * @param {string} url
     * @param {StatusCode} statusCode
     * @throws {AppwriteException}
     * @returns {Promise<Models.ProxyRule>}
     */
    createRedirectRule(domain: string, url: string, statusCode: StatusCode): Promise<Models.ProxyRule>;
    /**
     * Create a new proxy rule for serving Appwrite Site on custom domain.
     *
     * @param {string} domain
     * @param {string} siteId
     * @param {string} branch
     * @throws {AppwriteException}
     * @returns {Promise<Models.ProxyRule>}
     */
    createSiteRule(domain: string, siteId: string, branch?: string): Promise<Models.ProxyRule>;
    /**
     * Get a proxy rule by its unique ID.
     *
     * @param {string} ruleId
     * @throws {AppwriteException}
     * @returns {Promise<Models.ProxyRule>}
     */
    getRule(ruleId: string): Promise<Models.ProxyRule>;
    /**
     * Delete a proxy rule by its unique ID.
     *
     * @param {string} ruleId
     * @throws {AppwriteException}
     * @returns {Promise<{}>}
     */
    deleteRule(ruleId: string): Promise<{}>;
    /**
     * Retry getting verification process of a proxy rule. This endpoint triggers domain verification by checking DNS records (CNAME) against the configured target domain. If verification is successful, a TLS certificate will be automatically provisioned for the domain.
     *
     * @param {string} ruleId
     * @throws {AppwriteException}
     * @returns {Promise<Models.ProxyRule>}
     */
    updateRuleVerification(ruleId: string): Promise<Models.ProxyRule>;
}
